@@ -1,7 +1,7 @@
 from office365.runtime.client_object import ClientObject
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.update_entity_query import UpdateEntityQuery
-from office365.runtime.paths.resource_path import ResourcePath
 
 
 class Entity(ClientObject):
@@ -41,6 +41,12 @@ class Entity(ClientObject):
 
     def set_property(self, name, value, persist_changes=True):
         super(Entity, self).set_property(name, value, persist_changes)
-        if name == "id" and self._resource_path is None:
-            self._resource_path = ResourcePath(value, self._parent_collection.resource_path)
+        if name == "id":
+            if self._resource_path is None:
+                if type(self.parent_collection.resource_path) is ResourcePath:
+                    self._resource_path = ResourcePath(value, self.parent_collection.resource_path)
+                else:
+                    self._resource_path = self.parent_collection.resource_path.normalize(value)
+            else:
+                self._resource_path.normalize(value, inplace=True)
         return self
