@@ -1,7 +1,9 @@
 from office365.entity_collection import EntityCollection
+from office365.onedrive.internal.paths.root_path import RootPath
+from office365.onedrive.internal.paths.site_path import SitePath
 from office365.onedrive.sites.site import Site
+from office365.runtime.queries.read_entity_query import ReadEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.paths.resource_path import ResourcePath
 
 
 class SitesWithRoot(EntityCollection):
@@ -10,6 +12,16 @@ class SitesWithRoot(EntityCollection):
     def __init__(self, context, resource_path):
         super(SitesWithRoot, self).__init__(context, Site, resource_path)
 
+    def get_by_url(self, url):
+        """Address Site resource by absolute url
+
+        :param str url: Site absolute url
+        """
+        return_type = Site(self.context, SitePath(url, self.resource_path))
+        qry = ReadEntityQuery(return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def remove(self, sites):
         """
         :type sites: SitesWithRoot
@@ -25,6 +37,5 @@ class SitesWithRoot(EntityCollection):
 
     @property
     def root(self):
-        return self.properties.get('root',
-                                   Site(self.context, ResourcePath("root", self.resource_path)))
+        return self.properties.get('root', Site(self.context, RootPath(self.resource_path)))
 
