@@ -7,9 +7,6 @@ class ClientValue(object):
     containing entity or as a temporary value
     """
 
-    def __init__(self):
-        super(ClientValue, self).__init__()
-
     def set_property(self, k, v, persist_changes=True):
         prop_type = getattr(self, k, None)
         if isinstance(prop_type, ClientValue) and v is not None:
@@ -20,20 +17,33 @@ class ClientValue(object):
             setattr(self, k, prop_type)
         else:
             setattr(self, k, v)
+        return self
 
     def get_property(self, k):
         return getattr(self, k)
 
+    def __iter__(self):
+        for n, v in vars(self).items():
+            yield n, v
+
     def to_json(self, json_format=None):
         """
         :type json_format: office365.runtime.odata.odata_json_format.ODataJsonFormat or None
         """
-        json = dict((k, v) for k, v in vars(self).items() if v is not None)
+
+        def include(val):
+            from office365.runtime.client_value_collection import ClientValueCollection
+            if val is None:
+                return False
+            elif isinstance(val, ClientValueCollection) and len(val) == 0:
+                return False
+            return True
+
+        json = {k: v for k, v in self if include(v)}
         for n, v in json.items():
             if isinstance(v, ClientValue):
                 json[n] = v.to_json(json_format)
-
-        if isinstance(json_format, JsonLightFormat) and json_format.is_verbose and self.entity_type_name is not None:
+        if isinstance(json_format, JsonLightFormat) and json_format.include_control_information() and self.entity_type_name is not None:
             json[json_format.metadata_type_tag_name] = {'type': self.entity_type_name}
 
         return json
