@@ -1,8 +1,8 @@
-from office365.runtime.client_object_collection import ClientObjectCollection
+from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.comments.comment import Comment
 
 
-class CommentCollection(ClientObjectCollection):
+class CommentCollection(BaseEntityCollection):
 
     def __init__(self, context, resource_path=None):
         super(CommentCollection, self).__init__(context, Comment, resource_path)
