@@ -9,7 +9,8 @@ from office365.sharepoint.changes.change_query import ChangeQuery
 from office365.sharepoint.comments.comment_collection import CommentCollection
 from office365.sharepoint.fields.field_lookup_value import FieldLookupValue
 from office365.sharepoint.fields.fieldMultiLookupValue import FieldMultiLookupValue
-from office365.sharepoint.likes.likedByInformation import LikedByInformation
+from office365.sharepoint.likes.liked_by_information import LikedByInformation
+from office365.sharepoint.listitems.form_update_value import ListItemFormUpdateValue
 from office365.sharepoint.listitems.list_item_version import ListItemVersion
 from office365.sharepoint.permissions.securable_object import SecurableObject
 from office365.sharepoint.reputationmodel.reputation import Reputation
@@ -30,7 +31,7 @@ class ListItem(SecurableObject):
         """
 
         :type context: office365.sharepoint.client_context.ClientContext
-        :type resource_path: office365.runtime.client_path.ClientPath or None
+        :type resource_path: office365.runtime.paths.resource_path.ResourcePath or None
         :type parent_list: office365.sharepoint.lists.list.List or None
         """
         super(ListItem, self).__init__(context, resource_path)
@@ -39,7 +40,10 @@ class ListItem(SecurableObject):
 
     def set_rating(self, value):
         """
-        :type value: int
+        Rates an item within the specified list. The return value is the average rating for the specified list item.
+
+        :param int value: An integer value for the rating to be submitted.
+            The rating value SHOULD be between 1 and 5; otherwise, the server SHOULD return an exception.
         """
         return_value = ClientResult(self.context)
 
@@ -50,7 +54,11 @@ class ListItem(SecurableObject):
 
     def set_like(self, value):
         """
-        :type value: bool
+        Sets or unsets the like quality for the current user for an item within
+           the specified list. The return value is the total number of likes for the specified list item.
+
+        :param bool value: A Boolean value that indicates the operation being either like or unlike.
+            A True value indicates like.
         """
         return_value = ClientResult(self.context)
 
@@ -63,7 +71,9 @@ class ListItem(SecurableObject):
         """
         Gets the full URL to the SharePoint frame page that initiates the SPWOPIAction object with the WOPI
             application associated with the list item.
-        :param int action:
+
+
+        :param int action: Indicates which user action is indicated in the returned WOPIFrameUrl.
         """
         result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "GetWOPIFrameUrl", [action], None, None, result)
@@ -146,51 +156,69 @@ class ListItem(SecurableObject):
 
     def get_sharing_information(self):
         """
+        Retrieves information about the sharing state for a given list item.
 
-        :rtype: ObjectSharingInformation
         """
-        result = ClientResult(self.context, ObjectSharingInformation(self.context))
+        return_type = ObjectSharingInformation(self.context)
 
         def _item_resolved():
-            result.value = ObjectSharingInformation.get_list_item_sharing_information(
-                self.context, self.parent_list.properties["Id"], self.properties["Id"])
+            ObjectSharingInformation.get_list_item_sharing_information(
+                self.context, self.parent_list.properties["Id"], self.properties["Id"], return_type=return_type)
 
         self.ensure_properties(["Id", "ParentList"], _item_resolved)
-        return result.value
+        return return_type
 
-    def validate_update_list_item(self, form_values, new_document_update):
-        """Validates and sets the values of the specified collection of fields for the list item."""
-        qry = ServiceOperationQuery(self,
-                                    "validateUpdateListItem",
-                                    None,
-                                    {
-                                        "formValues": form_values,
-                                        "bNewDocumentUpdate": new_document_update,
-                                    })
+    def validate_update_list_item(self, form_values, new_document_update=False, checkin_comment=None,
+                                  dates_in_utc=None):
+        """Validates and sets the values of the specified collection of fields for the list item.
+
+        :param dict form_values: Specifies a collection of field internal names and values for the given field
+        :param dict new_document_update: Specifies whether the list item is a document being updated after upload.
+        :param str checkin_comment: Check-in comment, if any. This parameter is only applicable when the list item
+             is checked out.
+        :param bool or None dates_in_utc:
+        """
+        normalized_form_values = [ListItemFormUpdateValue(k, v) for k, v in form_values.items()]
+        payload = {
+            "formValues": normalized_form_values,
+            "bNewDocumentUpdate": new_document_update,
+            "checkInComment": checkin_comment,
+            "datesInUTC": dates_in_utc
+        }
+        result = ClientResult(self.context, ClientValueCollection(ListItemFormUpdateValue))
+        qry = ServiceOperationQuery(self, "ValidateUpdateListItem", None, payload, None, result)
         self.context.add_query(qry)
-        return self
+        return result
 
     def update(self):
+        """
+        Updates the item without creating another version of the item.
+        Exceptions:
+        - 2130575305 Microsoft.SharePoint.SPException List item was modified on the server in a way that prevents
+            changes from being committed, as determined by the protocol server.
+        -1 System.InvalidOperationException List does not support this operation.
+
+        """
         self.ensure_type_name(self.parent_list)
         super(ListItem, self).update()
         return self
 
     def system_update(self):
         """Update the list item."""
-        qry = ServiceOperationQuery(self,
-                                    "systemUpdate")
+        qry = ServiceOperationQuery(self, "SystemUpdate")
         self.context.add_query(qry)
         return self
 
     def update_overwrite_version(self):
-        """Update the list item."""
-        qry = ServiceOperationQuery(self,
-                                    "updateOverwriteVersion")
+        """Updates the item without creating another version of the item."""
+        qry = ServiceOperationQuery(self, "UpdateOverwriteVersion")
         self.context.add_query(qry)
         return self
 
     def set_comments_disabled(self, value):
         """
+        Sets the value of CommentsDisabled (section 3.2.5.87.1.1.8) for the item.
+
         :type value: bool
         """
         qry = ServiceOperationQuery(self, "SetCommentsDisabled", [value])
@@ -199,7 +227,7 @@ class ListItem(SecurableObject):
 
     def get_comments(self):
         comments = CommentCollection(self.context)
-        qry = ServiceOperationQuery(self, "getComments", [], None, None, comments)
+        qry = ServiceOperationQuery(self, "GetComments", [], None, None, comments)
         self.context.add_query(qry)
         return comments
 
