@@ -3,7 +3,7 @@ from office365.runtime.client_value import ClientValue
 
 class ResourcePath(ClientValue):
 
-    def __init__(self, decoded_url):
+    def __init__(self, decoded_url=None):
         super(ResourcePath, self).__init__()
         self.DecodedUrl = decoded_url
 
@@ -12,4 +12,4 @@ class ResourcePath(ClientValue):
         return "SP.ResourcePath"
 
     def __str__(self):
-        return "DecodedUrl='{0}'".format(self.DecodedUrl)
+        return str(self.DecodedUrl)
