@@ -1,7 +1,7 @@
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.userprofiles.followedContent import FollowedContent
+from office365.sharepoint.userprofiles.followed_content import FollowedContent
 
 
 class UserProfile(BaseEntity):
