@@ -30,10 +30,10 @@ from office365.sharepoint.principal.group_collection import GroupCollection
 from office365.sharepoint.principal.user import User
 from office365.sharepoint.principal.user_collection import UserCollection
 from office365.sharepoint.pushnotifications.push_notification_subscriber import PushNotificationSubscriber
-from office365.sharepoint.recyclebin.recycleBinItemCollection import RecycleBinItemCollection
+from office365.sharepoint.recyclebin.item_collection import RecycleBinItemCollection
 from office365.sharepoint.sharing.externalSharingSiteOption import ExternalSharingSiteOption
-from office365.sharepoint.sharing.objectSharingSettings import ObjectSharingSettings
-from office365.sharepoint.sharing.sharingLinkData import SharingLinkData
+from office365.sharepoint.sharing.object_sharing_settings import ObjectSharingSettings
+from office365.sharepoint.sharing.sharing_link_data import SharingLinkData
 from office365.sharepoint.sharing.sharing_result import SharingResult
 from office365.sharepoint.sites.site_types import SiteCollectionCorporateCatalogAccessor
 from office365.sharepoint.tenant.administration.tenant_types import TenantCorporateCatalogAccessor
@@ -46,6 +46,19 @@ from office365.sharepoint.webs.regional_settings import RegionalSettings
 from office365.sharepoint.webs.web_information_collection import WebInformationCollection
 from office365.sharepoint.webs.web_template_collection import WebTemplateCollection
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
+from office365.runtime.compat import urlparse
+
+
+def _create_safe_url(context, url, relative=True):
+    """
+    :type context: office365.sharepoint.client_context.ClientContext
+    :type url: str
+    :type relative: bool
+    """
+    site_path = urlparse(context.base_url).path
+    root_site_url = context.base_url.replace(site_path, "")
+    result = url if url.startswith(site_path) else "/".join([site_path, url])
+    return result if relative else "".join([root_site_url, result])
 
 
 class Web(SecurableObject):
@@ -115,7 +128,7 @@ class Web(SecurableObject):
 
         :param office365.sharepoint.client_context.ClientContext context:
         :param str url: he URL of the site, with the path of the object in SharePoint that is represented as query
-            string parameters, forSharing set to 1 if sharing, and mbypass set to 1 to bypass any mobile logic.
+            string parameters, forSharing set to 1 if sharing, and bypass set to 1 to bypass any mobile logic.
         :param bool is_edit_link: If true, the link will allow the logged in user to edit privileges on the item.
         """
         result = ClientResult(context)
@@ -125,6 +138,27 @@ class Web(SecurableObject):
         context.add_query(qry)
         return result
 
+    @staticmethod
+    def destroy_organization_sharing_link(context, url, is_edit_link, remove_associated_sharing_link_group):
+        """ Removes an existing organization link for an object.
+
+        :param office365.sharepoint.client_context.ClientContext context: SharePoint client context
+        :param str url: the URL of the site, with the path of the object in SharePoint that is represented as query
+            string parameters, forSharing set to 1 if sharing, and bypass set to 1 to bypass any mobile logic.
+        :param bool is_edit_link: If true, the link will allow the logged in user to edit privileges on the item.
+        :param bool remove_associated_sharing_link_group: Indicates whether to remove the groups that contain the users
+            who have been given access to the shared object via the sharing link
+        """
+        payload = {
+            "url": url,
+            "isEditLink": is_edit_link,
+            "removeAssociatedSharingLinkGroup": remove_associated_sharing_link_group
+            }
+        qry = ServiceOperationQuery(context.web, "DestroyOrganizationSharingLink", None, payload, None, None)
+        qry.static = True
+        context.add_query(qry)
+        return context.web
+
     @staticmethod
     def get_context_web_information(context):
         """
@@ -277,9 +311,10 @@ class Web(SecurableObject):
         """
         :type decoded_url: str
         """
+        safe_decoded_url = _create_safe_url(self.context, decoded_url)
         return_list = List(self.context)
         self.lists.add_child(return_list)
-        qry = ServiceOperationQuery(self, "GetListUsingPath", SPResPath(decoded_url), None, None, return_list)
+        qry = ServiceOperationQuery(self, "GetListUsingPath", SPResPath(safe_decoded_url), None, None, return_list)
         self.context.add_query(qry)
         return return_list
 
@@ -297,8 +332,9 @@ class Web(SecurableObject):
 
         :param str link_url: A URL that is either a tokenized sharing link or a canonical URL for a document
         """
-        result = SharingLinkData()
-        qry = ServiceOperationQuery(self, "GetSharingLinkData", [link_url], None, None, result)
+        result = ClientResult(self.context, SharingLinkData())
+        payload = {"linkUrl": link_url}
+        qry = ServiceOperationQuery(self, "GetSharingLinkData", None, payload, None, result)
         self.context.add_query(qry)
         return result
 
@@ -325,7 +361,7 @@ class Web(SecurableObject):
         """
         result = ClientResult(context)
         payload = {
-            "url": context.base_url + url,
+            "url": _create_safe_url(context, url, False),
             "isEditLink": is_edit_link
         }
         qry = ServiceOperationQuery(context.web, "CreateAnonymousLink", None, payload, None, result)
@@ -336,31 +372,31 @@ class Web(SecurableObject):
     @staticmethod
     def get_object_sharing_settings(context, object_url, group_id, use_simplified_roles):
         """Given a path to an object in SharePoint, this will generate a sharing settings object which contains
-        necessary information for rendering sharing information..
+        necessary information for rendering sharing information
 
         :param office365.sharepoint.client_context.ClientContext context: SharePoint client
         :param str object_url: A URL with one of two possible formats.
               The two possible URL formats are:
               1) The URL of the site, with the path of the object in SharePoint represented as query string parameters,
               forSharing set to 1 if sharing, and mbypass set to 1 to bypass any mobile logic
-              e.g. http://contoso.com/?forSharing=1&mbypass=1&List=%7BCF908473%2D72D4%2D449D%2D8A53%2D4BD01EC54B84%7D&
+              e.g. https://contoso.com/?forSharing=1&mbypass=1&List=%7BCF908473%2D72D4%2D449D%2D8A53%2D4BD01EC54B84%7D&
               obj={CF908473-72D4-449D-8A53-4BD01EC54B84},1,DOCUMENT
               2) The URL of the SharePoint object (web, list, item) intended for sharing
-              e.g. http://contoso.com/Documents/SampleFile.docx
+              e.g. https://contoso.com/Documents/SampleFile.docx
         :param int group_id: The id value of the permissions group if adding to a group, 0 otherwise.
         :param bool use_simplified_roles: A Boolean value indicating whether to use the SharePoint
         simplified roles (Edit, View) or not.
         """
-        result = ObjectSharingSettings(context)
+        return_type = ObjectSharingSettings(context)
         payload = {
             "objectUrl": object_url,
             "groupId": group_id,
             "useSimplifiedRoles": use_simplified_roles
         }
-        qry = ServiceOperationQuery(context.web, "GetObjectSharingSettings", None, payload, None, result)
+        qry = ServiceOperationQuery(context.web, "GetObjectSharingSettings", None, payload, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     def get_file_by_server_relative_url(self, url):
         """Returns the file object located at the specified server-relative URL.
@@ -384,6 +420,7 @@ class Web(SecurableObject):
 
     def get_folder_by_server_relative_url(self, url):
         """Returns the folder object located at the specified server-relative URL.
+
         :type url: str
         """
         return Folder(
@@ -416,7 +453,7 @@ class Web(SecurableObject):
         """Checks whether the specified logon name belongs to a valid user of the website, and if the logon name does
         not already exist, adds it to the website.
 
-        :type login_name: str
+        :param str login_name: Specifies a string that contains the login name.
         """
         target_user = User(self.context)
         self.site_users.add_child(target_user)
@@ -426,7 +463,8 @@ class Web(SecurableObject):
 
     def get_user_effective_permissions(self, user_name):
         """Gets the effective permissions that the specified user has within the current application scope.
-        :type user_name: str
+
+        :param str user_name: Specifies the user login name.
         """
         result = ClientResult(self.context, BasePermissions())
         qry = ServiceOperationQuery(self, "GetUserEffectivePermissions", [user_name], None, None, result)
@@ -445,7 +483,10 @@ class Web(SecurableObject):
 
     def does_push_notification_subscriber_exist(self, device_app_instance_id):
         """
-        :type device_app_instance_id: str
+        Specifies whether the push notification subscriber exists for the current user
+            with the given device  app instance identifier.
+
+        :param str device_app_instance_id: Device application instance identifier.
         """
         result = ClientResult(self.context)
         params = {"deviceAppInstanceId": device_app_instance_id}
@@ -455,8 +496,9 @@ class Web(SecurableObject):
 
     def get_folder_by_id(self, unique_id):
         """
+        Returns the folder object with the specified GUID.
 
-        :type unique_id: str
+        :param str unique_id: A GUID that identifies the folder.
         """
         folder = Folder(self.context)
         qry = ServiceOperationQuery(self, "GetFolderById", [unique_id], None, None, folder)
@@ -476,13 +518,14 @@ class Web(SecurableObject):
         return List(self.context,
                     ServiceOperationPath("defaultDocumentLibrary", None, self.resource_path))
 
-    def get_list(self, url):
-        """Get list by url
+    def get_list(self, path):
+        """Get list by path
 
-        :type url: str
+        :type path: str
         """
+        safe_path = _create_safe_url(self.context, path)
         return List(self.context,
-                    ServiceOperationPath("getList", [url], self.resource_path))
+                    ServiceOperationPath("getList", [safe_path], self.resource_path))
 
     def get_changes(self, query):
         """Returns the collection of all changes from the change log that have occurred within the scope of the site,
@@ -515,6 +558,14 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
+    def increment_site_client_tag(self):
+        """
+        Increments the client cache control number for this site collection.
+        """
+        qry = ServiceOperationQuery(self, "IncrementSiteClientTag")
+        self.context.add_query(qry)
+        return self
+
     def apply_web_template(self, web_template):
         """
         Applies the specified site definition or site template to the website that has no template applied to it.
@@ -543,7 +594,21 @@ class Web(SecurableObject):
         :param str guest_url: The guest access URL to get the file with.
         """
         return_type = File(self.context)
-        qry = ServiceOperationQuery(self, "GetFileByGuestUrl", [guest_url], None, None, return_type)
+        payload = {"guestUrl": guest_url}
+        qry = ServiceOperationQuery(self, "GetFileByGuestUrl", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
+    def get_file_by_linking_url(self, linking_url):
+        """
+        Returns the file object from the linking URL.
+
+        :param str linking_url: The linking URL to return the file object for.
+            A linking URL can be obtained from LinkingUrl.
+        """
+        return_type = File(self.context)
+        payload = {"linkingUrl": linking_url}
+        qry = ServiceOperationQuery(self, "GetFileByLinkingUrl", None, payload, None, return_type)
         self.context.add_query(qry)
         return return_type
 
@@ -637,6 +702,23 @@ class Web(SecurableObject):
         context.add_query(qry)
         return result
 
+    @staticmethod
+    def default_document_library_url(context, web_url):
+        """
+        Returns the default document library URL.
+
+        :param office365.sharepoint.client_context.ClientContext context: SharePoint context
+        :param str web_url:  URL of the web.
+        """
+        result = ClientResult(context, DocumentLibraryInformation())
+        payload = {
+            "webUrl": web_url,
+        }
+        qry = ServiceOperationQuery(context.web, "DefaultDocumentLibraryUrl", None, payload, None, result)
+        qry.static = True
+        context.add_query(qry)
+        return result
+
     @staticmethod
     def get_document_and_media_libraries(context, web_full_url, include_page_libraries):
         """
@@ -697,8 +779,8 @@ class Web(SecurableObject):
     @staticmethod
     def share_object(context, url, people_picker_input,
                      role_value=None,
-                     groupId=0, propagateAcl=False,
-                     send_email=True, includeAnonymousLinkInEmail=False, email_subject=None, email_body=None,
+                     group_id=0, propagate_acl=False,
+                     send_email=True, include_anonymous_link_in_email=False, email_subject=None, email_body=None,
                      use_simplified_roles=True):
         """
         This method shares an object in SharePoint such as a list item or site. It returns a SharingResult object
@@ -709,10 +791,10 @@ class Web(SecurableObject):
         :param str url: The URL of the website with the path of an object in SharePoint query string parameters.
         :param str role_value: The sharing role value for the type of permission to grant on the object.
         :param str people_picker_input: A string of JSON representing users in people picker format.
-        :param int groupId: The ID of the group to be added. Zero if not adding to a permissions group.
-        :param bool propagateAcl:  A flag to determine if permissions SHOULD be pushed to items with unique permissions.
+        :param int group_id: The ID of the group to be added. Zero if not adding to a permissions group.
+        :param bool propagate_acl:  A flag to determine if permissions SHOULD be pushed to items with unique permissions.
         :param bool send_email: A flag to determine if an email notification SHOULD be sent (if email is configured).
-        :param bool includeAnonymousLinkInEmail: If an email is being sent, this determines if an anonymous link
+        :param bool include_anonymous_link_in_email: If an email is being sent, this determines if an anonymous link
         SHOULD be added to the message.
         :param str email_subject: The email subject.
         :param str email_body: The email subject.
@@ -723,11 +805,11 @@ class Web(SecurableObject):
         result = SharingResult(context)
         payload = {
             "url": url,
-            "groupId": groupId,
+            "groupId": group_id,
             "peoplePickerInput": people_picker_input,
             "roleValue": role_value,
-            "includeAnonymousLinkInEmail": includeAnonymousLinkInEmail,
-            "propagateAcl": propagateAcl,
+            "includeAnonymousLinkInEmail": include_anonymous_link_in_email,
+            "propagateAcl": propagate_acl,
             "sendEmail": send_email,
             "emailSubject": email_subject,
             "emailBody": email_body,
@@ -927,6 +1009,7 @@ class Web(SecurableObject):
 
     @property
     def site_collection_app_catalog(self):
+        """Returns the site collection app catalog for the given web if it exists."""
         return self.properties.get('SiteCollectionAppCatalog',
                                    SiteCollectionCorporateCatalogAccessor(self.context,
                                                                           ResourcePath("SiteCollectionAppCatalog",
@@ -935,6 +1018,7 @@ class Web(SecurableObject):
     @property
     def url(self):
         """Gets the absolute URL for the website.
+
         :rtype: str or None
         """
         return self.properties.get('Url', None)
@@ -942,6 +1026,7 @@ class Web(SecurableObject):
     @property
     def quick_launch_enabled(self):
         """Gets a value that specifies whether the Quick Launch area is enabled on the site.
+
         :rtype: bool or None
         """
         return self.properties.get('QuickLaunchEnabled', None)
@@ -949,6 +1034,7 @@ class Web(SecurableObject):
     @quick_launch_enabled.setter
     def quick_launch_enabled(self, value):
         """Sets a value that specifies whether the Quick Launch area is enabled on the site.
+
         :type value: bool
         """
         self.set_property('QuickLaunchEnabled', value)
@@ -956,6 +1042,7 @@ class Web(SecurableObject):
     @property
     def site_logo_url(self):
         """Gets a value that specifies Site logo url.
+
         :rtype: str or None
         """
         return self.properties.get('SiteLogoUrl', None)
@@ -971,6 +1058,7 @@ class Web(SecurableObject):
     @property
     def web_template(self):
         """Gets the name of the site definition or site template that was used to create the site.
+
         :rtype: str or None
         """
         return self.properties.get('WebTemplate', None)
