@@ -1,7 +1,7 @@
 from office365.entity import Entity
 from office365.entity_collection import EntityCollection
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.teams.channels.channel import Channel
 from office365.teams.channels.channel_collection import ChannelCollection
 from office365.teams.shifts.schedule import Schedule
@@ -9,8 +9,8 @@ from office365.teams.team_fun_settings import TeamFunSettings
 from office365.teams.team_guest_settings import TeamGuestSettings
 from office365.teams.team_member_settings import TeamMemberSettings
 from office365.teams.team_messaging_settings import TeamMessagingSettings
-from office365.teams.apps.teams_app_installation import TeamsAppInstallation
-from office365.teams.operations.teams_async_operation import TeamsAsyncOperation
+from office365.teams.apps.app_installation import TeamsAppInstallation
+from office365.teams.operations.async_operation import TeamsAsyncOperation
 from office365.teams.teams_template import TeamsTemplate
 
 
@@ -19,6 +19,7 @@ class Team(Entity):
     logical isolation of discussion, within a team. """
 
     def delete_object(self):
+        """Deletes a team"""
         def _team_loaded():
             group = self.context.groups[self.id]
             group.delete_object(False)
@@ -185,6 +186,15 @@ class Team(Entity):
         see sending Teams activity notifications:
         https://docs.microsoft.com/en-us/graph/teams-send-activityfeednotifications
 
+        :param teamworkActivityTopic topic: Topic of the notification. Specifies the resource being talked about.
+        :param str activity_type: Activity type. This must be declared in the Teams app manifest.
+        :param str chain_id: Optional. Used to override a previous notification. Use the same chainId in subsequent
+            requests to override the previous notification.
+        :param str preview_text: Preview text for the notification. Microsoft Teams will only show first 150 characters
+        :param dict template_parameters: Values for template variables defined in the activity feed entry corresponding
+            to activityType in Teams app manifest.
+        :param teamworkNotificationRecipient template_parameters: Recipient of the notification.
+             Only Azure AD users are supported.
         """
         payload = {
             "topic": topic,
@@ -210,6 +220,6 @@ class Team(Entity):
     def set_property(self, name, value, persist_changes=True):
         super(Team, self).set_property(name, value, persist_changes)
         # fallback: determine whether resource path is resolved
-        if name == "id" and self._resource_path.segment == "team":
+        if name == "id" and self._resource_path.name == "team":
             self._resource_path = ResourcePath(value, ResourcePath("teams"))
         return self
